@@ -23,7 +23,7 @@
  * Credits      :                                                          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-conc.c,v 1.76 2004/05/09 22:48:03 enlf Exp $
+/* $Id: m-conc.c,v 1.79 2004/10/16 20:36:34 enlf Exp $
  */
 
 /*
@@ -722,6 +722,7 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
   MdcConcReconTypes recon_type=-1;
   float osem2d_recon_zoom=-1;
   float calibration_factor=1.0;
+  float isotope_branching_factor=1.0;
   int i_bed, i_gate, i_frame, i_plane, img;
   Int32 high_file_pointer, low_file_pointer;
   Uint32 number;
@@ -736,10 +737,13 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
   int num_garbage_lines = 0;
   char failed_to_read_64_bit=MDC_FALSE;
   long plane_bytes;
-    
+  char transmission_scan = MDC_FALSE;
+
 
   if (MDC_VERBOSE) MdcPrntMesg("CONC Reading <%s> ...",fi->ifname);
 
+  /* initialize */
+  fi->modality = M_PT;
 
   /* read through the header, looking at all the tokens */
   done = MDC_FALSE;
@@ -782,11 +786,7 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
       base_filename[0]='\0';
       if (fi->idir != NULL) {
         strncpy(base_filename, fi->idir, MDC_MAX_PATH);
-#ifdef MDC_DOS
-        strncat(base_filename,"\\", MDC_MAX_PATH);
-#else
-        strncat(base_filename,"/", MDC_MAX_PATH);
-#endif
+        strncat(base_filename, MDC_PATH_DELIM_STR, MDC_MAX_PATH);
       }
       strncat(base_filename, pfilename, MDC_MAX_PATH);
       if (MDC_INFO) MdcPrntScrn("Base name of raw data file:\t%s\n",pfilename);
@@ -826,22 +826,31 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
       if (MDC_INFO) MdcPrntScrn("Acquisition type:\t\t%d=%s\n",
                                 temp_int,MdcConcAcqModeNames[acq_type]);
       switch(acq_type) {
+      case MDC_CONC_ACQ_BLANK:
+        fi->acquisition_type = MDC_ACQUISITION_STATIC;
+	break;
+      case MDC_CONC_ACQ_EMISSION:
+        fi->acquisition_type = MDC_ACQUISITION_TOMO;
+	break;
       case MDC_CONC_ACQ_DYNAMIC:
         fi->acquisition_type = MDC_ACQUISITION_DYNAMIC;
         break;
-      case MDC_CONC_ACQ_CONTINUOUS:
-      case MDC_CONC_ACQ_EMISSION:
-      case MDC_CONC_ACQ_WINDOWED_COINCIDENCE:
-      case MDC_CONC_ACQ_NON_WINDOWED_COINCIDENCE:
-        fi->acquisition_type = MDC_ACQUISITION_TOMO;
-        break;
       case MDC_CONC_ACQ_GATED:
         fi->acquisition_type = MDC_ACQUISITION_GATED;
         break;
-      case MDC_CONC_ACQ_BLANK:
+      case MDC_CONC_ACQ_CONTINUOUS:
+        fi->acquisition_type = MDC_ACQUISITION_TOMO;
+	break;
       case MDC_CONC_ACQ_SINGLES:
         fi->acquisition_type = MDC_ACQUISITION_STATIC;
+	transmission_scan = MDC_TRUE;
         break;
+      case MDC_CONC_ACQ_WINDOWED_COINCIDENCE:
+      case MDC_CONC_ACQ_NON_WINDOWED_COINCIDENCE:
+        fi->acquisition_type = MDC_ACQUISITION_TOMO;
+	transmission_scan = MDC_TRUE;
+        break;
+      case MDC_CONC_ACQ_UNKNOWN:
       default:
         fi->acquisition_type = MDC_ACQUISITION_UNKNOWN;
         break;
@@ -884,9 +893,7 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
       break;
     case MDC_CONC_HDR_ISOTOPE_BRANCHING_FRACTION:
       temp_float = conc_get_float(line, &return_code);
-#if MDC_ENABLE_ISOTOPE_BRANCHING_FRACTION
-      calibration_factor /= temp_float;
-#endif
+      isotope_branching_factor = temp_float;
       if (MDC_INFO)
         MdcPrntScrn("Isotope branching fraction:\t%5.3f\n",temp_float);
       break;
@@ -1622,6 +1629,12 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
   }
 
 
+#if MDC_ENABLE_ISOTOPE_BRANCHING_FRACTION
+  /* adjust the calibration factor with the branching factor if needed */
+  if (!transmission_scan)
+    calibration_factor /= isotope_branching_factor;
+#endif
+
   /* need to open up the raw data file */
   fi->ifp_raw = fopen(raw_filename, "rb");
 
@@ -1845,7 +1858,6 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
     /* and read in the info for the first plane, and the rest of the planes */
     for(i_plane=0; i_plane < fi->dim[3]; i_plane++, img++) {
       plane = &fi->image[img];
-      strcpy(plane->image_mod, "PT"); 
       plane->calibr_fctr = calibration_factor;
 
       if (i_plane != 0) {
