@@ -14,7 +14,7 @@
  *                MdcHandleArgs()         - Handle the arguments           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-getopt.c,v 1.113 2004/05/02 21:12:28 enlf Exp $
+/* $Id: m-getopt.c,v 1.121 2004/11/08 23:30:28 enlf Exp $
  */
 
 /*
@@ -56,15 +56,6 @@
 
 #include "medcon.h"
 
-/****************************************************************************
-                              D E F I N E S 
-****************************************************************************/
-
-/* global arrays for argument handling */
-char *mdc_arg_files[MDC_MAX_FILES];    /* pointers to filenames         */
-int   mdc_arg_convs[MDC_MAX_FRMTS];    /* counter for each conversion   */
-int   mdc_arg_total[2];                /* totals for files & conversion */
-
 /****************************************************************************
                             F U N C T I O N S
 ****************************************************************************/
@@ -271,9 +262,10 @@ Format DICOM:\n\
 #endif
 #if MDC_INCLUDE_INTF
   MdcPrntScrn("\
-\nFormat InterFile: [-skip1 -nopath]\n\
+\nFormat InterFile: [-skip1 -nopath -one]\n\
 \n  -skip1, --skip-preview-slice  skip first preview slice\
 \n  -nopath, --ignore-path        ignore path in \'name of data file\' key\
+\n  -one, --single-file           write header and image to same file\
 \n");
 #endif
 
@@ -297,10 +289,11 @@ Reslicing: [-tra|-sag|-cor]\n\
 \n  -cor, --coronal               reslice images coronal\
 \n");
   MdcPrntScrn("\n\
-Debug/Extras: [-d -v -db -hackacr -ean]\n\
+Debug/Mode: [-d -v -db -hackacr -ean]\n\
 \n  -d, --debug                   give debug information (printout FI)\
+\n  -s, --silent                  force silent mode, suppress all messages\
 \n  -v, --verbose                 run in verbose mode\
-\n  -db, --database               print database info (ECAT)\
+\n  -db, --database               print database info\
 \n  -ean, --echo-alias-name       echo alias name on screen\
 \n");
 #if MDC_INCLUDE_ACR
@@ -327,7 +320,7 @@ void MdcPrintShortInfo(void)
   }else{
     MdcPrntScrn("Try \'medcon --help\' for more information.\n\n");
 #ifdef _WIN32
-    MdcWaitForEnter(-1);
+    fflush(NULL); MdcWaitForEnter(-1);
 #endif
   }
 }
@@ -443,7 +436,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
        if (XMDC_GUI == MDC_NO) {
          MDC_ECHO_ALIAS = MDC_YES;
          MDC_INFO = MDC_NO;
-         MDC_BLOCK_MESSAGES = MDC_LEVEL_WARN;
+         if (MDC_BLOCK_MESSAGES == MDC_NO) MDC_BLOCK_MESSAGES = MDC_LEVEL_WARN;
        }
        continue;
      }else if ( (strcasecmp(argv[a],"-noprefix") == 0) ||
@@ -705,6 +698,9 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
      }else if ( (strcasecmp(argv[a],"-nopath") == 0) ||
                 (strcasecmp(argv[a],"--ignore-path") == 0) ) {
        MDC_IGNORE_PATH=MDC_YES; continue;
+     }else if ( (strcasecmp(argv[a],"-one") == 0) ||
+                (strcasecmp(argv[a],"--single-file") == 0) ) {
+       MDC_SINGLE_FILE=MDC_YES; continue;
      }else if ( (strcasecmp(argv[a],"-tra") == 0) ||
                 (strcasecmp(argv[a],"--transverse") == 0) ) {
        MDC_RESLICE = MDC_TRANSAXIAL;  continue;
@@ -751,6 +747,9 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
                                               ,&mdc_crop_width
                                               ,&mdc_crop_height);
        continue;
+     }else if ( (strcasecmp(argv[a],"-s") == 0) ||
+                (strcasecmp(argv[a],"--silent") == 0) ) {
+       MDC_BLOCK_MESSAGES = MDC_LEVEL_ALL; continue;
      }
      
      if ( ARG == -1 ) return(MDC_BAD_CODE);              /* no '-c' or '-f' */
@@ -970,6 +969,10 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
 
     if (MDC_INTERACTIVE == MDC_YES)
       MdcPrntErr(MDC_NO_CODE,"Interactive read impossible with stdout");
+
+    if (MDC_SINGLE_FILE == MDC_YES)
+      MdcPrntErr(MDC_NO_CODE,"Single file output unsupported with stdout");
+
   }
   /* checks related to file input from stdin */
   if (MDC_FILE_STDIN == MDC_YES) {
