@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-global.c,v 1.62 2004/05/02 21:12:28 enlf Exp $
+/* $Id: m-global.c,v 1.65 2004/11/06 23:49:25 enlf Exp $
  */
 
 /*
@@ -66,6 +66,11 @@ Int8 MDC_BLOCK_MESSAGES = MDC_NO;
 char prefix[MDC_MAX_PREFIX + 1]="eNlf-"; /* 15 + '\O' */
 char *mdcbasename=NULL;                  /* new base  */
 
+/* global arrays for argument handling */
+char *mdc_arg_files[MDC_MAX_FILES];    /* pointers to filenames         */
+int   mdc_arg_convs[MDC_MAX_FRMTS];    /* counter for each conversion   */
+int   mdc_arg_total[2];                /* totals for files & conversion */
+
 char FrmtString[MDC_MAX_FRMTS][15]= {
     "Unknown      ",    /* MDC_FRMT_NONE  */
     "Raw Binary   ",    /* MDC_FRMT_RAW   */
@@ -96,15 +101,18 @@ char FrmtExt[MDC_MAX_FRMTS][8] = {
     "hdr",    /* MDC_FRMT_ANLZ  */
     "dcm",    /* MDC_FRMT_DICM  */
     "png",    /* MDC_FRMT_PNG   */
-    "img.hdr" /* MDC_FRMT_CONC  */   
-};
+    "img.hdr" /* MDC_FRMT_CONC  */
   /*"..."                       */
+};
 
 char mdcbufr[MDC_2KB_OFFSET+1]; /* 2KB global buffer */
 char errmsg[MDC_1KB_OFFSET+1];  /* 1KB error  buffer */
 
+/* user specified slope/intercept */
 float mdc_si_slope     = 1.;
 float mdc_si_intercept = 0.;
+
+/* user specified window center/width */
 float mdc_cw_center    = 0.;
 float mdc_cw_width     = 0.;
 
@@ -121,45 +129,63 @@ Uint32 mdc_crop_width   = 0;
 Uint32 mdc_crop_height  = 0;
 
 /* flags & options */
-char MDC_INSTITUTION[MDC_MAXSTR]="UZGENT"; /* name of institution             */
-Int8 MDC_COLOR_MODE=  MDC_COLOR_RGB;       /* default color mode              */
-Int8 MDC_COLOR_MAP =  MDC_MAP_GRAY; /* gray color palette selected            */
-Int8 MDC_ANLZ_SPM  =  MDC_NO;   /* Analyze for SPM with use of scaling factor */
-Int8 MDC_ANLZ_OPTIONS = MDC_NO; /* Analyze for SPM & user supplied parameters */
+char MDC_INSTITUTION[MDC_MAXSTR]="UZGENT"; /* name of institution           */
+
+Int8 MDC_COLOR_MODE=  MDC_COLOR_RGB;    /* default color mode               */
+Int8 MDC_COLOR_MAP =  MDC_MAP_GRAY;     /* gray color palette selected      */
+
+Int8 MDC_ANLZ_SPM  =  MDC_NO;           /* Analyze/SPM with scaling factor  */
+Int8 MDC_ANLZ_OPTIONS = MDC_NO;         /* Analyze/SPM request parameters   */
+
 Int8 MDC_DICOM_MOSAIC_ENABLED = MDC_NO;    /* DICOM: mosaic support enabled   */
 Int8 MDC_DICOM_MOSAIC_FORCED  = MDC_NO;    /* DICOM: mosaic preset  forced    */
 Int8 MDC_DICOM_MOSAIC_DO_INTERL = MDC_NO;  /* DICOM: mosaic forced interlaced */
 Int8 MDC_DICOM_MOSAIC_FIX_VOXEL = MDC_NO;  /* DICOM: mosaic fix voxel sizes   */
-Int8 MDC_DICOM_CONTRAST= MDC_NO;           /* DICOM: enable contrast window   */
+Int8 MDC_DICOM_CONTRAST = MDC_NO;          /* DICOM: enable contrast window   */
 Int8 MDC_DICOM_WRITE_IMPLICIT = MDC_NO;    /* DICOM: write little implicit    */
 Int8 MDC_DICOM_WRITE_NOMETA = MDC_NO;      /* DICOM: write without meta header*/
-Int8 MDC_FORCE_RESCALE = MDC_NO; /* apply user specified slope/intercept      */
-Int8 MDC_FORCE_CONTRAST= MDC_NO; /* apply user specified window center/width  */
-Int8 MDC_INFO=MDC_YES;
-Int8 MDC_INTERACTIVE=MDC_NO, MDC_CONVERT=MDC_NO;
-Int8 MDC_EXTRACT=MDC_NO, MDC_NEGATIVE=MDC_NO;
-Int8 MDC_PIXELS=MDC_NO, MDC_PIXELS_PRINT_ALL=MDC_NO;
-Int8 MDC_QUANTIFY=MDC_NO, MDC_CALIBRATE=MDC_NO, MDC_DEBUG=MDC_NO;
-Int8 MDC_GIF_OPTIONS=MDC_NO;
-Int8 MDC_MAKE_GRAY=MDC_NO, MDC_DITHER_COLOR=MDC_NO;
-Int8 MDC_VERBOSE=MDC_NO, MDC_RENAME=MDC_NO;
+
+Int8 MDC_FORCE_RESCALE = MDC_NO;        /* user specified slope/intercept   */
+Int8 MDC_FORCE_CONTRAST= MDC_NO;        /* user specified center/width      */
+
+Int8 MDC_INFO = MDC_YES;                /* default print header info        */
+Int8 MDC_INTERACTIVE = MDC_NO;          /* interactive read of raw file     */
+Int8 MDC_CONVERT = MDC_NO;              /* image conversion requested       */
+Int8 MDC_EXTRACT = MDC_NO;              /* extract images                   */
+Int8 MDC_RENAME = MDC_NO;               /* rename base filename             */
+Int8 MDC_ECHO_ALIAS = MDC_NO;           /* echo alias name based on ID's    */
+Int8 MDC_EDIT_FI = MDC_NO;              /* edit FILEINFO struct             */
+
+Int8 MDC_PIXELS = MDC_NO;               /* print specified pix values       */
+Int8 MDC_PIXELS_PRINT_ALL = MDC_NO;     /* print    all    pix values       */
+
+Int8 MDC_NEGATIVE = MDC_NO;             /* allow negative pixel values      */
+Int8 MDC_QUANTIFY = MDC_NO;             /* quantitation with one factor     */
+Int8 MDC_CALIBRATE = MDC_NO;            /* quantitation with two factors    */
+
+Int8 MDC_DEBUG = MDC_NO;                /* give debug info                  */
+Int8 MDC_VERBOSE = MDC_NO;              /* run in verbose mode              */
+
+Int8 MDC_GIF_OPTIONS = MDC_NO;          /* request for extra GIF options    */
+
+Int8 MDC_MAKE_GRAY = MDC_NO;            /* forced remap color to gray scale */
+Int8 MDC_DITHER_COLOR = MDC_NO;         /* apply dither on color reduction  */
+
 Int8 MDC_NORM_OVER_FRAMES = MDC_NO;     /* normalize over images in a frame */
                                         /* instead of all images            */
 Int8 MDC_SKIP_PREVIEW = MDC_NO;         /* skip the first (preview) slice   */
 Int8 MDC_IGNORE_PATH = MDC_NO;          /* ignore path in INTF data fname   */
+Int8 MDC_SINGLE_FILE = MDC_NO;          /* write INTF as single file        */
 Int8 MDC_FORCE_INT = MDC_NO;            /* force integer pixels             */
 Int8 MDC_INT16_BITS_USED = 16;          /* bits to use for Int16 type       */
 Int8 MDC_TRUE_GAP = MDC_NO;             /* spacing = true gap/overlap       */
 Int8 MDC_ALIAS_NAME = MDC_NO;           /* use  alias name based on ID's    */
-Int8 MDC_ECHO_ALIAS = MDC_NO;           /* echo alias name based on ID's    */
 Int8 MDC_PREFIX_DISABLED = MDC_NO;      /* prevent the prefix in names      */
 Int8 MDC_PREFIX_ACQ = MDC_NO;           /* use acquisition number as prefix */
 Int8 MDC_PREFIX_SER = MDC_NO;           /* use series      number as prefix */
-Int8 MDC_RESLICE = MDC_NO;              /* reslice images (tra, sag, cor)   */
 
 Int8 MDC_PATIENT_ANON = MDC_NO;         /* make patient anonymous           */
 Int8 MDC_PATIENT_IDENT = MDC_NO;        /* give patient identification      */
-Int8 MDC_EDIT_FI = MDC_NO;              /* edit FILEINFO struct             */
 Int8 MDC_FILE_OVERWRITE = MDC_NO;       /* allow file overwriting           */
 Int8 MDC_FILE_STDIN  = MDC_NO;          /* input from stdin  stream         */
 Int8 MDC_FILE_STDOUT = MDC_NO;          /* output  to stdout stream         */ 
@@ -173,6 +199,7 @@ Int8 MDC_SORT_CINE_APPLY = MDC_NO;      /* cine apply sorting               */
 Int8 MDC_SORT_CINE_UNDO  = MDC_NO;      /* cine undo  sorting               */
 Int8 MDC_MAKE_SQUARE     = MDC_NO;      /* make square image                */
 Int8 MDC_CROP_IMAGES     = MDC_NO;      /* crop image dimensions            */
+Int8 MDC_RESLICE = MDC_NO;              /* reslice images (tra, sag, cor)   */
 
 Int8 MDC_FRMT_INPUT = MDC_FRMT_NONE;    /* format used for stdin            */ 
 Int8 MDC_ECAT_SORT = MDC_ANATOMICAL;    /* ECAT sort order                  */
@@ -190,10 +217,10 @@ Int8 MDC_FALLBACK_FRMT = MDC_FRMT_NONE;
 #endif
 
 /* undocumented options, for debugging purposes only */
-Int8 MDC_MY_DEBUG=MDC_NO;
-Int8 MDC_INFO_DB=MDC_NO;
-Int8 MDC_HACK_ACR=MDC_NO;
+Int8 MDC_MY_DEBUG=MDC_NO;               /* give even more debug info        */
+Int8 MDC_INFO_DB=MDC_NO;                /* just print short database info   */
+Int8 MDC_HACK_ACR=MDC_NO;               /* try to find acrnema tags         */
 
 /* XMedCon - GUI*/
-Int8 XMDC_GUI=MDC_NO;                /* is program the GUI part? */
-Int8 XMDC_WRITE_FRMT = MDC_FRMT_RAW; /* default format to save   */
+Int8 XMDC_GUI=MDC_NO;                   /* is program the GUI part?         */
+Int8 XMDC_WRITE_FRMT = MDC_FRMT_RAW;    /* default format to save           */
