@@ -23,7 +23,7 @@
  *                                                                         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xcolmap.c,v 1.24 2004/01/04 22:36:17 enlf Exp $
+/* $Id: xcolmap.c,v 1.25 2004/09/23 22:24:13 enlf Exp $
  */
 
 /*
@@ -577,11 +577,8 @@ gboolean XMdcChangeLUT(GtkWidget *spinner, gpointer data)
   sprintf(lutname,"ct%03d.lut",nr);
   if (XMEDCONLUT != NULL) { 
     strncpy(xmdcstr,XMEDCONLUT,MDC_1KB_OFFSET); xmdcstr[strlen(xmdcstr)]='\0';
-#ifdef MDC_DOS
-     if (xmdcstr[strlen(xmdcstr)-1] != '\\' ) strcat(xmdcstr,"\\"); 
-#else
-     if (xmdcstr[strlen(xmdcstr)-1] != '/' ) strcat(xmdcstr,"/");
-#endif
+     if (xmdcstr[strlen(xmdcstr)-1] != MDC_PATH_DELIM_CHR)
+       strcat(xmdcstr,MDC_PATH_DELIM_STR); 
   }else{
     /* installation dir */
     strncpy(xmdcstr,XMDCLUT,MDC_1KB_OFFSET);    xmdcstr[strlen(xmdcstr)]='\0';
