@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xdefs.h,v 1.52 2004/02/13 23:41:50 enlf Exp $
+/* $Id: xdefs.h,v 1.58 2004/11/07 00:15:43 enlf Exp $
  */
 
 /*
@@ -61,13 +61,17 @@
 #define XMDC_LABEL_STYLE_PAGE  2
 #define XMDC_LABEL_STYLE_ECAT  3
 
-#define XMDC_ZOOM_FACTOR       2
-#define XMDC_ZOOM_MAX          8 
+#define XMDC_ZOOM_FACTOR       1
+#define XMDC_ZOOM_IN          XMDC_ZOOM_FACTOR   /* incr */
+#define XMDC_ZOOM_OUT       -(XMDC_ZOOM_FACTOR)  /* decr */
+#define XMDC_ZOOM_NONE         0
 
-#define XMDC_RESIZE_ORIGINAL   1                   /* nothing       */
-#define XMDC_RESIZE_FOURTH   -(XMDC_ZOOM_FACTOR*2) /* divide   by 4 */
-#define XMDC_RESIZE_HALF     -(XMDC_ZOOM_FACTOR)   /* divide   by 2 */
-#define XMDC_RESIZE_DOUBLE    (XMDC_ZOOM_FACTOR)   /* multiply by 2 */
+#define XMDC_RESIZE_FOURTH    -4   /* 1:4 */
+#define XMDC_RESIZE_THIRD     -3   /* 1:3 */
+#define XMDC_RESIZE_HALF      -2   /* 1:2 */
+#define XMDC_RESIZE_ORIGINAL   1   /* 1:1 */
+#define XMDC_RESIZE_DOUBLE     2   /* 2:1 */
+#define XMDC_RESIZE_TRIPLE     3   /* 3:1 */
 
 #define XMDC_PAGES_FRAME_BY_FRAME 0                   /* frame by frame */
 #define XMDC_PAGES_SLICE_BY_SLICE 1                   /* slice by slice */
@@ -136,6 +140,7 @@ typedef struct OptionsMedConStruct_t {
         GtkWidget *AnlzSPM;
         GtkWidget *IntfSkip1;
         GtkWidget *IntfNoPath;
+        GtkWidget *IntfSingleFile;
         GtkWidget *EcatSortAnatom;
         GtkWidget *EcatSortByFrame;
 }OptionsMedConStruct;
@@ -162,6 +167,10 @@ typedef struct MyMainStruct_t {
     Uint32 images_horizontal, images_vertical;
     Uint32 startimage, real_images_on_page;
     Uint32 *pagenumber, *imagenumber, *realnumber;
+
+    Int8 RESIZE;
+    float scale_width, scale_height;
+
 }MyMainStruct;
 
 
@@ -243,8 +252,10 @@ typedef struct ResizeSelectionStruct_t {
    Int8 CurType;
    GtkWidget *Original;
    GtkWidget *Fourth;
+   GtkWidget *Third;
    GtkWidget *Half;
    GtkWidget *Double;
+   GtkWidget *Triple;
 }ResizeSelectionStruct;
 
 typedef struct PagesSelectionStruct_t{
@@ -293,6 +304,9 @@ typedef struct EditFileInfoStruct_t {
   GtkWidget *Planar;
   GtkWidget *ModalityNM;
   GtkWidget *ModalityPT;
+  GtkWidget *ModalityCT;
+  GtkWidget *ModalityMR;
+  GtkWidget *ModalityCurrent;
   GtkWidget *AcquisitionType[MDC_MAX_ACQUISITIONS];
 }EditFileInfoStruct;
 
