@@ -29,7 +29,7 @@
  *                XMdcInitCineButtons()            - Init cine buttons     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xoptions.c,v 1.60 2004/01/04 22:36:17 enlf Exp $
+/* $Id: xoptions.c,v 1.61 2004/11/07 00:15:43 enlf Exp $
  */
 
 /*
@@ -305,7 +305,11 @@ void XMdcOptionsMedconCallbackApply(GtkWidget *widget, gpointer data)
   }else{
     MDC_IGNORE_PATH=MDC_NO;
   }
-
+  if (GTK_TOGGLE_BUTTON(sOptionsMedCon.IntfSingleFile)->active) {
+    MDC_SINGLE_FILE=MDC_YES;
+  }else{
+    MDC_SINGLE_FILE=MDC_NO;
+  }
 
   /* Concorde microPET */
 
@@ -942,7 +946,7 @@ void XMdcOptionsMedconAddTabFormats(GtkWidget *notebook)
   /* ECAT 6.4 */
   frame = gtk_frame_new("Ecat 6");
   gtk_container_set_border_width(GTK_CONTAINER(frame),5);
-  gtk_table_attach_defaults(GTK_TABLE(table),frame,0,1,0,1);
+  gtk_table_attach_defaults(GTK_TABLE(table),frame,1,2,1,2);
   gtk_widget_show(frame);
 
   box3 = gtk_vbox_new(FALSE,0);
@@ -976,7 +980,7 @@ void XMdcOptionsMedconAddTabFormats(GtkWidget *notebook)
   /* InterFile */
   frame = gtk_frame_new("InterFile");
   gtk_container_set_border_width(GTK_CONTAINER(frame),5);
-  gtk_table_attach_defaults(GTK_TABLE(table),frame,1,2,1,2);
+  gtk_table_attach_defaults(GTK_TABLE(table),frame,0,1,0,1);
   gtk_widget_show(frame);
 
   box3 = gtk_vbox_new(FALSE,0);
@@ -1004,6 +1008,15 @@ void XMdcOptionsMedconAddTabFormats(GtkWidget *notebook)
   gtk_widget_set_sensitive(button,FALSE);
 #endif
 
+  button = gtk_check_button_new_with_label("[w]  write into a single file");
+  gtk_box_pack_start(GTK_BOX(box3),button,TRUE,TRUE,0);
+  if (MDC_SINGLE_FILE == MDC_YES)
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+  gtk_widget_show(button);
+  sOptionsMedCon.IntfSingleFile = button;
+#if ! MDC_INCLUDE_INTF
+  gtk_widget_set_sensitive(button,FALSE);
+#endif
 }
 
 void XMdcOptionsMedconAddTabMosaic(GtkWidget *notebook)
@@ -1545,6 +1558,12 @@ void XMdcOptionsMedconSel(GtkWidget *widget, gpointer data)
      else
        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1), FALSE);
 
+     b1 = sOptionsMedCon.IntfSingleFile;
+     if (MDC_SINGLE_FILE == MDC_YES)
+       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1), TRUE);
+     else
+       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1), FALSE);
+
 
      /* ECAT 6 */
      b1 = sOptionsMedCon.EcatSortAnatom;
